 /* If you want to update the appearance of the GUI, please make changes to the `qt_stylesheet.scss` file. */
* {
  font-family: "Dosis", sans-serif;
  /*font-size: 12px;*/
  color: #333333; }

QGroupBox {
  border: 1px solid #254342;
  border-radius: 4px;
  margin-top: 10px;
  font-weight: bold; }

QGroupBox {
  background-color: #a4d6d9; }

QStatusBar {
  color: #365d5f; }

QMainWindow {
  background-color: #365d5f; }

QTabWidget::pane {
  border: 1px solid white;
  top: 1px;
  background: cadetblue; }

QTabBar::tab {
  border: 1px solid;
  padding: 5px;
  color: #365d5f;
  border-top-left-radius: 20px;
  border-top-right-radius: 5px;
  /*min-width: 200px;*/ }

QTabBar::tab {
  background: white;
  border-color: #365d5f;
  margin-bottom: -5px;
  font-weight: bolder;
  font-size: 16px; }

QTabBar::tab:selected {
  background: #365d5f;
  color: white;
  border-color: white; }

QPushButton {
  font-weight: bold;
  border-radius: 4px;
  border: 2px solid #29394a;
  background-color: #29394a;
  color: white; }

QPushButton:disabled {
  background-color: #7983b1;
  border: 1px solid #7983b1;
  color: #a4d6d9; }

QPushButton:hover {
  border: 3px solid white; }

QPushButton#start_recording_button {
  font-size: 18px;
  background-color: #d95158; }

QPushButton#start_recording_button:disabled {
  background-color: #8c5454; }

QPushButton#stop_recording_button {
  font-size: 18px; }

QPushButton#stop_recording_button:enabled {
  /*font-size: 24px;*/
  border: 3px solid #d95158; }

WelcomeScreenButton {
  border: 2px solid #333333;
  background-color: #365d5f;
  color: white;
  font-size: 24px;
  border-radius: 20px;
  padding: 10px; }

WelcomeScreenButton[recommended_next=true] {
  background-color: #d95158;
  color: white; }

QLabel {
  font-size: 14px;
  color: #333333; }

QLabel:disabled {
  color: #a4d6d9; }

QLineEdit {
  border: 1px solid #29394a;
  border-radius: 4px;
  padding: 0 8px;
  color: #333333; }

QLineEdit:disabled {
  color: #333333;
  background-color: #29394a; }

QTreeView {
  background-color: #7983b1;
  alternate-background-color: #a3b1ed;
  color: white;
  font-weight: bold;
  font-family: "Roboto", sans-serif;
  font-size: 12px; }

QTreeView::item:has-children {
  background-color: #29394a;
  color: white; }

QTreeView::item:selected,
QTreeView::item:hover {
  background-color: white;
  color: #333333; }

LogViewWidget {
  background-color: #254342;
  color: white;
  font-family: "Roboto", sans-serif;
  font-size: 12px;
  padding: 8px; }
